@@ -52,6 +52,25 @@
  *			Module interfaces				*
  *									*
  ************************************************************************/
+/**
+ * xsltFixImportedCompSteps:
+ * @master: the "master" stylesheet
+ * @style: the stylesheet being imported by the master
+ *
+ * normalize the comp steps for the stylesheet being imported
+ * by the master, together with any imports within that. 
+ *
+ */
+static void xsltFixImportedCompSteps(xsltStylesheetPtr master, 
+			xsltStylesheetPtr style) {
+    xsltStylesheetPtr res;
+    xmlHashScan(style->templatesHash,
+	            (xmlHashScanner) xsltNormalizeCompSteps, master);
+    master->extrasNr += style->extrasNr;
+    for (res = style->imports; res != NULL; res = res->next) {
+        xsltFixImportedCompSteps(master, res);
+    }
+}
 
 /**
  * xsltParseStylesheetImport:
@@ -119,11 +138,8 @@ xsltParseStylesheetImport(xsltStylesheetPtr style, xmlNodePtr cur) {
 	}
     }
 
-#ifdef XSLT_PARSE_OPTIONS
-    import = xmlReadFile((const char *) URI, NULL, XSLT_PARSE_OPTIONS);
-#else
-    import = xmlParseFile((const char *) URI);
-#endif
+    import = xsltDocDefaultLoader(URI, style->dict, XSLT_PARSE_OPTIONS,
+                                  (void *) style, XSLT_LOAD_STYLESHEET);
     if (import == NULL) {
 	xsltTransformError(NULL, style, cur,
 	    "xsl:import : unable to load %s\n", URI);
@@ -134,9 +150,9 @@ xsltParseStylesheetImport(xsltStylesheetPtr style, xmlNodePtr cur) {
     if (res != NULL) {
 	res->next = style->imports;
 	style->imports = res;
-	xmlHashScan(res->templatesHash, 
-	            (xmlHashScanner) xsltNormalizeCompSteps, style);
-	style->extrasNr += res->extrasNr;
+	if (style->parent == NULL) {
+	    xsltFixImportedCompSteps(style, res);
+	}
 	ret = 0;
     } else {
 	xmlFreeDoc(import);
@@ -170,6 +186,7 @@ xsltParseStylesheetInclude(xsltStylesheetPtr style, xmlNodePtr cur) {
     xmlChar *base = NULL;
     xmlChar *uriRef = NULL;
     xmlChar *URI = NULL;
+    xsltStylesheetPtr result;
     xsltDocumentPtr include;
     xsltDocumentPtr docptr;
 
@@ -217,13 +234,13 @@ xsltParseStylesheetInclude(xsltStylesheetPtr style, xmlNodePtr cur) {
     /* chain to stylesheet for recursion checking */
     include->includes = style->includes;
     style->includes = include;
-    ret = (int)xsltParseStylesheetProcess(style, include->doc);
+    result = xsltParseStylesheetProcess(style, include->doc);
     style->includes = include->includes;
     style->doc = oldDoc;
-    if (ret == 0) {
-		ret = -1;
-		goto error;
-	}
+    if (result == NULL) {
+	ret = -1;
+	goto error;
+    }
     ret = 0;
 
 error:
