@@ -47,7 +47,7 @@
 /* #define WITH_XSLT_DEBUG_BLANKS */
 #endif
 
-const char *xsltEngineVersion = LIBXSLT_VERSION_STRING;
+const char *xsltEngineVersion = LIBXSLT_VERSION_STRING LIBXSLT_VERSION_EXTRA;
 const int xsltLibxsltVersion = LIBXSLT_VERSION;
 const int xsltLibxmlVersion = LIBXML_VERSION;
 
@@ -1496,6 +1496,11 @@ xsltParseTemplateContent(xsltStylesheetPtr style, xmlNodePtr templ) {
 	     * This is an element which will be output as part of the
 	     * template exectution, precompile AVT if found.
 	     */
+	    if ((cur->ns == NULL) && (style->defaultAlias != NULL) &&
+	    		(cur->type == XML_ELEMENT_NODE)) {
+		cur->ns = xmlSearchNsByHref(cur->doc, cur,
+			style->defaultAlias);
+	    }
 	    if (cur->properties != NULL) {
 	        xmlAttrPtr attr = cur->properties;
 
@@ -1899,7 +1904,8 @@ xsltParseStylesheetTop(xsltStylesheetPtr style, xmlNodePtr top) {
     } else if (IS_XSLT_NAME(cur, "namespace-alias")) {
 	    xsltNamespaceAlias(style, cur);
 	} else {
-            if ((style != NULL) && (style->doc->version != NULL) && (!strncmp(style->doc->version,"1.0",3))) {
+            if ((style != NULL) && (style->doc->version != NULL) &&
+	        (!strncmp((const char *) style->doc->version, "1.0", 3))) {
 	        xsltTransformError(NULL, style, cur,
 			"xsltParseStylesheetTop: unknown %s element\n",
 			cur->name);
@@ -2127,7 +2133,8 @@ xsltParseStylesheetFile(const xmlChar* filename) {
 	}
     }
 
-    doc = xmlReadFile((const char *) filename, NULL, XSLT_PARSE_OPTIONS);
+    doc = xsltDocDefaultLoader(filename, NULL, XSLT_PARSE_OPTIONS,
+                               NULL, XSLT_LOAD_START);
     if (doc == NULL) {
 	xsltTransformError(NULL, NULL, NULL,
 		"xsltParseStylesheetFile : cannot parse %s\n", filename);
